pub struct Client { /* private fields */ }Expand description
Client for the CentOS Build System (CBS) Koji XML-RPC API.
Implementations
Sourceimpl Client
impl Client
pub fn new() -> Self
pub fn with_hub_url(hub_url: &str) -> Self
Sourcepub fn get_package_id(&self, name: &str) -> Result<Option<i64>, Box<dyn Error>>
pub fn get_package_id(&self, name: &str) -> Result<Option<i64>, Box<dyn Error>>
Look up the numeric package ID for a package name.
Sourcepub fn list_builds(&self, package_id: i64) -> Result<Vec<Build>, Box<dyn Error>>
pub fn list_builds(&self, package_id: i64) -> Result<Vec<Build>, Box<dyn Error>>
List completed builds for a package, newest first.
List tag names for a given build ID.
Sourcepub fn hyperscale_summary(
&self,
builds: &[Build],
el_version: u32,
) -> Result<HyperscaleSummary, Box<dyn Error>>
pub fn hyperscale_summary( &self, builds: &[Build], el_version: u32, ) -> Result<HyperscaleSummary, Box<dyn Error>>
Find the latest Hyperscale release and testing builds for an EL version.
Walks builds newest-first, checking tags for each. Returns the latest build in release, and the latest build in testing if it’s newer than the release build.